@@ -56,7 +56,7 @@ public class GtkCheckboxPeer extends GtkComponentPeer
                                    boolean state);
   public native void nativeSetCheckboxGroup (GtkCheckboxGroupPeer group);
   public native void connectSignals ();
-  public native void gtkSetFont (String name, int style, int size);
+  native void gtkSetFont (String name, int style, int size);
   public native void gtkSetLabel (String label);
 
   public GtkCheckboxPeer (Checkbox c)
@@ -87,11 +87,6 @@ public class GtkCheckboxPeer extends GtkComponentPeer
     gtkSetLabel (label);
   }
 
-  public void setFont (Font f)
-  {
-    gtkSetFont(f.getName(), f.getStyle(), f.getSize());
-  }
-
   public void setCheckboxGroup (CheckboxGroup group)
   {
     GtkCheckboxGroupPeer gp
